@@ -1,4 +1,4 @@
-#!/usr/share/ucs-test/runner pytest-3 -s -l -vv
+#!/usr/share/ucs-test/runner /usr/share/ucs-test/playwright
 ## desc: Test portal SSO login via keycloak
 ## tags: [keycloak]
 ## roles: [domaincontroller_master, domaincontroller_backup]
@@ -7,8 +7,7 @@
 from datetime import datetime, timedelta
 
 import pytest
-from selenium.webdriver.common.by import By
-from utils import keycloak_get_request, keycloak_password_change, keycloak_sessions_by_user, wait_for_id
+from utils import keycloak_get_request, keycloak_password_change, keycloak_sessions_by_user
 
 from univention.lib.umc import Unauthorized
 from univention.testing.umc import Client
@@ -45,8 +44,7 @@ def test_password_change_wrong_old_password_fails(portal_login_via_keycloak, key
 
 def test_password_change_same_passwords_fails(portal_login_via_keycloak, keycloak_config, portal_config, udm):
     username = udm.create_user(pwdChangeNextLogin=1)[1]
-    driver = portal_login_via_keycloak(username, 'univention', new_password='univention', fails_with='Changing password failed. The password was already used.')
-    wait_for_id(driver, keycloak_config.password_id)
+    portal_login_via_keycloak(username, 'univention', new_password='univention', fails_with='Changing password failed. The password was already used.')
 
 
 def test_password_change_new_password_too_short_fails(portal_login_via_keycloak, keycloak_config, portal_config, udm):
@@ -61,37 +59,33 @@ def test_password_change_new_password_too_short_fails(portal_login_via_keycloak,
 
 def test_password_change_confirm_new_passwords_fails(portal_login_via_keycloak, keycloak_config, portal_config, udm):
     username = udm.create_user(pwdChangeNextLogin=1)[1]
-    driver = portal_login_via_keycloak(
+    portal_login_via_keycloak(
         username,
         'univention',
         new_password='univention',
         new_password_confirm='univention1',
         fails_with="Passwords don't match.",
     )
-    wait_for_id(driver, keycloak_config.password_id)
 
 
 def test_password_change_empty_passwords_fails(portal_login_via_keycloak, keycloak_config, portal_config, udm):
     username = udm.create_user(pwdChangeNextLogin=1)[1]
-    driver = portal_login_via_keycloak(username, 'univention', verify_login=False)
-    wait_for_id(driver, keycloak_config.password_id)
+    page = portal_login_via_keycloak(username, 'univention', verify_login=False)
     # just click the button without old or new passwords
-    driver.find_element(By.ID, keycloak_config.password_change_button_id).click()
-    error = driver.find_element(By.CSS_SELECTOR, keycloak_config.password_update_error_css_selector)
-    assert error.text == 'Please specify password.', error.text
-    wait_for_id(driver, keycloak_config.password_id)
+    page.click(f"[id='{keycloak_config.password_change_button_id}']")
+    error = page.locator(keycloak_config.password_update_error_css_selector.replace("[class='", ".").replace("']", "").replace(" ", "."))
+    assert error.inner_text() == 'Please specify password.', error.inner_text()
 
 
 def test_password_change_after_second_try(portal_login_via_keycloak, keycloak_config, portal_config, udm):
     username = udm.create_user(pwdChangeNextLogin=1)[1]
-    driver = portal_login_via_keycloak(
+    page = portal_login_via_keycloak(
         username,
         'univention',
         new_password='univention',
         fails_with='Changing password failed. The password was already used.',
     )
-    keycloak_password_change(driver, keycloak_config, 'univention', 'Univention.99', 'Univention.99')
-    wait_for_id(driver, portal_config.header_menu_id)
+    keycloak_password_change(page, keycloak_config, 'univention', 'Univention.99', 'Univention.99')
     assert Client(username=username, password='Univention.99')
 
 
@@ -112,16 +106,15 @@ def test_password_change_expired_shadowLastChange(portal_login_via_keycloak, key
 
 def test_logout(portal_login_via_keycloak, portal_config, keycloak_config, udm):
     username = udm.create_user()[1]
-    driver = portal_login_via_keycloak(username, 'univention')
-    wait_for_id(driver, portal_config.header_menu_id).click()
+    page = portal_login_via_keycloak(username, 'univention')
+    page.click(f"[id='{portal_config.header_menu_id}']")
     sessions = keycloak_sessions_by_user(keycloak_config, username)
     assert sessions
-    logout = wait_for_id(driver, portal_config.logout_button_id)
-    lang = driver.execute_script('return window.navigator.userLanguage || window.navigator.language')
+    logout = page.locator(f"#{portal_config.logout_button_id}")
+    lang = page.evaluate('() => window.navigator.userLanguage || window.navigator.language')
     logout_msg = portal_config.logout_msg if lang == 'en-US' else portal_config.logout_msg_de
-    assert logout.text == logout_msg
+    assert logout.inner_text() == logout_msg
     logout.click()
-    wait_for_id(driver, portal_config.categories_id)
     sessions = keycloak_sessions_by_user(keycloak_config, username)
     assert not sessions
 
@@ -129,14 +122,13 @@ def test_logout(portal_login_via_keycloak, portal_config, keycloak_config, udm):
 def test_login_not_possible_with_deleted_user(keycloak_config, portal_login_via_keycloak, portal_config, udm):
     _dn, username = udm.create_user()
     # login
-    driver = portal_login_via_keycloak(username, 'univention')
+    page = portal_login_via_keycloak(username, 'univention')
     users = keycloak_get_request(keycloak_config, 'realms/ucs/users', params={'search': username})
     assert len(users) == 1
     assert users[0]['username'] == username
     # logout
-    wait_for_id(driver, portal_config.header_menu_id).click()
-    wait_for_id(driver, portal_config.logout_button_id).click()
-    wait_for_id(driver, portal_config.categories_id)
+    page.click(f"[id={portal_config.header_menu_id}]")
+    page.click(f"[id={portal_config.logout_button_id}]")
     sessions = keycloak_sessions_by_user(keycloak_config, username)
     assert not sessions
 
@@ -149,9 +141,9 @@ def test_login_not_possible_with_deleted_user(keycloak_config, portal_login_via_
     # if this bug is fixed, just
     #   assert portal_login_via_keycloak(username, "univention", fails_with=keycloak_config.wrong_password_msg)
     # should do it
-    driver = portal_login_via_keycloak(username, 'univention', verify_login=False)
-    error = wait_for_id(driver, 'kc-error-message')
-    assert error.text == 'Unexpected error when handling authentication request to identity provider.'
+    page = portal_login_via_keycloak(username, 'univention', verify_login=False)
+    error = page.locator("#kc-error-message")
+    assert error.inner_text() == 'Unexpected error when handling authentication request to identity provider.'
 
     # check that user is no longer available in keycloak
     users = keycloak_get_request(keycloak_config, 'realms/ucs/users', params={'search': username})
